#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
    "hstem":            6,      #184
#
    "vstem":            143,    #182    =straight vstem
    "vstem_curve":      140,    #156    =curve vstem
    "sarastem":         90,     #127
#
    "headdia":          129,    #387
    "headhole":         106,    #152   
    "headstem":         48,		#117      
    "headstem_plus_hole":   33,	#266
    "headstem_plus":    42,     #102   
    "headdia_plus":     188,    #410   
    "hstem_head":       89,     #164   
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          194,    #1120   =normal height 
    "vheight_shoot":    190,    #1147   =overshoot height
    "vheight_plus":     203,    #1073   =normal height 
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       181,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       202,    #10 
    "vheight_shoot_lo": 153,    #29 
    "vheight_lu":       188,    #410    =lo_lu
#
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "gap_25":         177,    #25     =front/rear spacing
    "gap_61":         72,     #61
    "gap_74":         85,     #74
    "gap_102":          42,     #102
    "gap_125":        91,     #125
    "gap_141":        92,     #141
    "gap_150":          78,     #150
    "gap_160":          12,     #160
    "gap_170":          74,     #170
    "gap_188":          4,      #188
    "gap_203":          16,     #203
    "gap_217":          23,     #217
    "gap_229":          14,     #229
    "gap_266":          97,     #266
    "gap_377":          198,    #377
#special
    "serif":            89,     #164
    "special_2":        88,     #20
}

##SKELETON
#DEPRECATED, USE shpix INSTEAD
##v-d: top vertical stem delta shift
##f_deltap   y 9+4  y 10+4  y 11+4  y 12+4  y 13+4  y 14+4  y 15+4  y 16+4  
#
##s-d: serif delta shift
##top
##f_deltap   y 9-4  y 10-4  y 11-4  y 12-4  y 13-4  y 14-4  y 15-4  y 16-4  
##bottom
##f_deltap   y 9+4  y 10+4  y 11+4  y 12+4  y 13+4  y 14+4  y 15+4  y 16+4  
#END DEPRECATED

#hd: head interpolate at 29 30 31 32 ppem
#f_deltap    y1 29-4 y2 29+4   y1 30-4 y2 30+4   y1 31-4 y2 31+4   y1 32-4 y2 32+4

#hd2: head delta shift - y
#f_deltap    y 9+8  y 10+8   y 11+8   y 12+8   y 13+4    y 14+8   y 15+8   y 16+8   y 21-8   y 27-8   y 28-8   y 37+8   y 44-8   y 49+8

#SHPIX
#vd: top vertical stem shift
#shpix  16 y

#sd: serif delta shift, use only middle serif
#shpix  -16 y 

#r1: sara level 1
#f_deltap    y 9+8   y 11+8   y 12+8   y 13+8   y 14+8   y 15+8   y 16+8   
######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
srp0    26
mdrp[rp0,min,rnd,white] 15
f_deltap	15 16+8  15 17-8  15 29-8  15 30-8  
mirp[rp0,min,rnd,grey]  hstem 12
srp0    15
mdrp[rp0,rnd,grey]  2
f_deltap    2 10-8  2 15+8  2 19-8  2 21-8  2 32-8
mirp[min,rnd,grey]  hstem  25
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     13
mirp[rp0,rnd,grey]  vheight_shoot   22
ip  8
ip  17
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
mdap[rnd]   8
mdrp[grey]  18
mdrp[grey]  19
mdap[rnd]   17
mdrp[grey]  9
mdrp[grey]  10
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
srp0	53
mdrp[rp0,rnd,white]	21
f_deltap    21 10+8  21 11+8  21 14-8
mdrp[rp0,rnd,grey]	15
f_deltap    15 11-8  15 19-8
ip  50
ip  44
mdrp[rp0,rnd,white] 7
mdrp[grey]  27
f_deltap    27 9-4  27 10-6 
mdrp[rp0,rnd,white] 2
f_deltap	2 23+8  2 28+8  2 29+8  2 30+8  2 31+8  2 32+8  
mirp[min,rnd,grey]  hstem   32
mdrp[rp0,rnd,grey]  36
f_deltap    36 10-8  36 13+8  36 25+8
mirp[min,rnd,grey]  hstem   39
#
IUP[x]
#
SVTCA[y-axis]
#
mdap[rnd]   0
mdrp[grey]  34
mirp[rnd,grey]      vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[rp0,min,rnd,grey]  12
f_deltap    12 9+8  12 10+8  12 11+8  12 14+8  12 15+8
mdrp[rp0,rnd,grey]  18
ip  47
ip  41
f_deltap    10 11-4  10 14-1  10 15-2
#
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
srp0    57
mdrp[rp0,rnd,white]  24
f_deltap    24 16+8  24 20-8
mdrp[grey]      13
mdrp[min,rnd,grey]  18
f_deltap    18 9-8  18 10-8  18 11-8  18 14-8
ip  54
ip  48
mdrp[rp0,rnd,grey]  7
f_deltap    7 15+8  7 19+8  7 27-8
mdrp[grey]  31
mdrp[rp0,rnd,grey]  2
f_deltap    2 21+8
mirp[min,rnd,grey]  hstem 36
mdrp[rp0,rnd,grey]  40
f_deltap    40 10-8  40 13+8  40 19-8  
mirp[min,rnd,grey]  hstem 43
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mdrp[grey]  38
mirp[rnd,grey]  vheight 41
mirp[rp0,rnd,grey] vheight_shoot 29
alignrp     27
mdrp[rp0,rnd,grey]  15
sloop   4
ip      28 11 10 9
mdrp[rnd,grey]  21
f_deltap    21 9+8  21 10+8  21 11+8
ip  51
ip  45
IUP[y]

""",

    #kho_kwai
    "uni0E04": """
srp0    51
mdrp[rp0,rnd,white] 32
mirp[min,rnd,grey]  hstem 8
f_deltap	8 14-1 8 17-3 8 19-3
mdrp[rnd,grey]      29
mdrp[rp0,rnd,grey]  14
f_deltap    14 11-8  14 12-8  14 14-8 14 17-8  14 19-8  
mdrp[rp0,rnd,grey]  20
f_deltap    20 13-8  20 18-8 
sloop   3
ip  25 48 42
mdrp[rp0,rnd,grey]  2
f_deltap	2 16+8  
mirp[min,rnd,grey]  hstem 38
srp0    29
mirp[min,rnd,grey]  hstem 28
ip  11
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             28
mdrp[rnd,grey]      11
MIRP[rp0,rnd,grey]  vheight_shoot  35
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
mdrp[rp0,min,rnd,grey]  17
mdap[rnd]       17
mdrp[rp0,rnd,grey]  23
sloop   3
ip  45 39 25
IUP[y]
""",

    #kho_kon
    "uni0E05": """
srp0    56
mdrp[rp0,rnd,white] 35
mirp[min,rnd,grey]  hstem 11
f_deltap	11 14-1  11 17-3  11 19-3
mdrp[rnd,grey]      32
mdrp[rp0,rnd,grey]  17
f_deltap    17 11-8  17 12-8  17 14-8  17 17-8  17 19-8  
mdrp[rp0,rnd,grey]  23
f_deltap    23 13-8  23 18-8 
sloop   3
ip  28 53 47
mdrp[rp0,rnd,grey]  2
f_deltap	2 16+8  
mirp[min,rnd,grey]  hstem 43
srp0    32
mirp[min,rnd,grey]  hstem 31
ip  14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             31
mdrp[rnd,grey]      14
MIRP[rp0,rnd,grey]  vheight_shoot  40
ALIGNRP             38
mdrp[grey]  5
f_deltap 	5 14+1  5 15+2  5 16+3
shp[rp2]	8
mdrp[rp0,min,rnd,grey]  39
mdrp[rp0,min,rnd,grey]  6
mdrp[rp0,rnd,white]  20
f_deltap	20 14-8
mdrp[rnd,grey]  26
sloop   3
ip  50 44 28
IUP[y]
""",

    #kho_rakhang
    "uni0E06": """
srp0    79
mdrp[rp0,rnd,grey]  37
f_deltap	37 13+8  37 16+8  37 20-8
mdrp[grey]  26
mdrp[rp0,rnd,grey]  31
f_deltap	31 13-8  31 28-8  31 29-8  
ip      64
ip      58
alignrp 14
mdrp[rp0,rnd,grey]  20
mdrp[grey]  44
srp0        14
mirp[rp0,rnd,grey]  hstem 50
alignrp     3
mdrp[rnd,grey]  9
f_deltap	9 12+8  9 16+8  
ip      76
ip      70
srp0        14
mdrp[rp0,rnd,grey]  53
f_deltap    53 19-8  53 23-8  53 24-8  53 27-8
alignrp     1
mirp[min,rnd,grey]  hstem 54
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     6
mdrp[grey]  52
mirp[rnd,grey]  vheight 53
mirp[rp0,rnd,grey]  vheight_shoot 42
alignrp     40
mdrp[grey]  22
mdrp[grey]  24
mdrp[rp0,rnd,grey]  28
mdrp[rnd,grey]  34
ip      61
ip      55
srp0    6
mdrp[rp0,rnd,grey]  12
sloop   4
ip      73 67 50 3
IUP[y]
""",

    #ngo_ngu
    "uni0E07": """
srp0    37
mdrp[rp0,rnd,grey]  22
ip      4
ip      5 
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]      17
f_deltap    17 12+8  17 13+4
ip      34
ip      28
mdrp[rp0,rnd,grey]  8
mdrp[grey]  1
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[grey]  8
mdrp[grey]  5
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[rp0,rnd,grey]  14
ip      31
ip      25
#
IUP[y]
""",

    #jo_jan
    "uni0E08": """
srp0    44
mdrp[rp0,min,rnd,grey]  7
ip      22
mdrp[rp0,rnd,grey]      12
f_deltap    12 12-8
ip      41
ip      35
mdrp[grey]  2
mdrp[rp0,rnd,grey]      29
f_deltap    29 11+8  29 15+8  29 19+8  29 21-8
ip      1
mirp[min,rnd,grey]      hstem 16
srp0    1
mdrp[grey]  13
mdrp[grey]  0
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mdrp[grey]  13
f_deltap    13 12-2  13 13-3  13 14-4  13 15-3  13 16-4
mirp[rp0,rnd,grey]  vheight_shoot 26
mdrp[rp0,grey]  19
f_deltap    19 14+1  19 15+2  19 16+3
mdrp[rp0,min,rnd,grey]  10
mdap[rnd]       10
mdrp[rnd,grey]  4
ip  38
ip  32
IUP[y]
""",

    #cho_ching
    "uni0E09": """
srp0    67
mdrp[rp0,rnd,grey]  12
f_deltap    12 10-8  12 14-8  12 21+8  12 30-8
alignrp 0
mdrp[rnd,grey]  7
f_deltap    7 12+8  7 13+4
ip  22
ip  52
ip  46
mirp[min,rnd,grey]  hstem 2
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,rnd,grey]  33
mdrp[rnd,grey]      39
ip  64
ip  58
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     36
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot  26
mdrp[rp0,grey]  19
f_deltap    19 14+1  19 15+2  19 16+3
mdrp[rp0,min,rnd,grey]  10
mdap[rnd]   10
mdrp[rnd,grey]  4
ip  49
ip  43
srp0    36
mdrp[rp0,rnd,grey]  30
alignrp 15
ip  55
ip  61
mdrp[grey]  41
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
srp0    62
mdrp[rp0,rnd,white] 21
f_deltap    21 9+8  21 10+8  21 11+8  21 14-8
mdrp[rp0,rnd,grey]  15                 
f_deltap    15 11-8  15 19-8           
ip  59
ip  53
mdrp[rp0,rnd,white] 7
mdrp[grey]  27
f_deltap    27 9-4  27 10-6 
mdrp[rp0,rnd,white] 2
mirp[min,rnd,grey]  hstem   32
mdrp[rp0,rnd,grey]  37
f_deltap    37 10-8  37 13+8
ip  39
mirp[min,rnd,grey]  hstem   47
ip  45
mdrp[rp0,rnd,grey]  42
mirp[min,rnd,grey]  hstem 43
#
IUP[x]
#
SVTCA[y-axis]
#
mdap[rnd]   0
mdrp[grey]  34
mirp[rp0,rnd,grey]  vheight_shoot 24
sloop   3
ip  39 45 40
mdrp[grey]  42
mdrp[rp0,min,rnd,grey]  12
f_deltap    12 9+8  12 10+8  12 11+8  12 14+8  12 15+8
mdrp[rp0,rnd,grey]  18
ip  56
ip  50
f_deltap    10 11-4  10 14-1  10 15-2
#
IUP[y]
""",

    #so_zo
    "uni0E0B": """
srp0    66
mdrp[rp0,rnd,white]  24
f_deltap    24 20-8  24 21-8  
mdrp[grey]      13
mdrp[min,rnd,grey]  18
f_deltap    18 9-8  18 10-8  18 11-8
ip  63
ip  57
mdrp[rp0,rnd,grey]  7
f_deltap    7 15+8  7 16+8  7 19+8  7 27-8
mdrp[grey]  31
mdrp[rp0,rnd,grey]  2
f_deltap    2 14+8  
mirp[min,rnd,grey]  hstem 36
mdrp[rp0,rnd,grey]  41
f_deltap    41 10-8  41 13+8  41 14-8  41 19-8  41 24-8  41 26-8
ip  43
mirp[min,rnd,grey]  hstem 51
ip  49
mdrp[rp0,rnd,grey]  46
mirp[min,rnd,grey]  hstem 47
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           0
mdrp[grey]  38
mirp[rp0,rnd,grey] vheight_shoot 29
sloop   3
ip  43 49 44
alignrp     27
mdrp[grey]  46
mdrp[rp0,rnd,grey]  15
sloop   4
ip      28 11 10 9
mdrp[rnd,grey]  21
f_deltap    21 9+8  21 10+8  21 11+8
ip  60
ip  54
IUP[y]
""",

    #cho_choe
    "uni0E0C": """
srp0    75
mdrp[rp0,rnd,white] 35
mirp[min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  13
f_deltap    13 12-8  13 17-8  13 19-8  13 20-8  13 21-8  13 22-8  13 23-8  13 24-8  13 26-8  13 27-8  13 28-8  13 29-8  13 30-8  13 33-8  13 34-8  13 36-8  13 37-8  13 39-8  13 40-8  
sloop   6
ip      50 54 29 9 72 21
mirp[min,rnd,grey]  hstem 45
mdrp[rp0,rnd,grey]  49
f_deltap    49 27-8  
alignrp     1
mirp[min,rnd,grey]  hstem 50
#
f_deltap    76 9+8 
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
alignrp 6
alignrp 32
mdrp[grey]  48
mirp[rnd,grey]  vheight 49
mirp[rp0,rnd,grey]  vheight_shoot 42
sloop   3
ip  37 20 21
mdrp[grey]  16
f_deltap    16 14+1  16 15+2  16 16+3
srp0    6
mdrp[rp0,rnd,grey]  46
alignrp 12
alignrp 26
sloop   5
ip  63 51 69 57 3
#
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
srp0    82
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  48
ip  42
mdrp[rp0,rnd,grey]  2
f_deltap    2 12-8  2 17-8  2 20-8  2 23-8  2 24-8  2 26-8  2 27-8  2 28-8  2 30-8  2 33-8  2 34-8  2 36-8  2 37-8  2 39-8  2 40-8
ip  26
ip  10
mirp[min,rnd,grey]  hstem 34
mdrp[rnd,grey]  54
mdrp[rp0,rnd,grey]  37
f_deltap    37 21-8  37 22-8  37 27-8  
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[grey]  67
srp0    54
mdrp[rnd,grey]  60
ip  79
ip  73
f_deltap    83 19+8  83 29+8
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     21
mdrp[grey]  35
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 31
ip          26
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    21
mdrp[rnd,grey]  15
ip  39
ip  45
srp0    0
mdrp[rp0,rnd,white] 57
mdrp[grey]  66
mdrp[rnd,grey]  51
ip  76
ip  70
ip  62
#
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
srp0    52
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  48
ip  42
mdrp[rp0,rnd,grey]  2
f_deltap    2 16-8  2 17-8  2 18-8  2 19-8  2 23-8  2 26-8  2 28-8  2 30-8  2 33-8 2 36-8  2 37-8  2 39-8  2 40-8 
ip  26
ip  10
mirp[min,rnd,grey]  hstem 34
mdrp[rp0,rnd,grey]  37
f_deltap    37 21-8  37 27-8
mirp[rp0,min,rnd,grey]  hstem 38
#                                          
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     21
mdrp[grey]  35
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 31
ip          26
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    21
mdrp[rnd,grey]  15
ip  39
ip  45
#
IUP[y]
""",

    #do_chada
    "uni0E0E": """
srp0    74
mdrp[rp0,rnd,grey]  29
f_deltap 29 18+8  29 21+8  29 22+8  29 26+8  29 31+8  
mirp[min,rnd,grey]  hstem 41
mdrp[rnd,grey]  35
f_deltap    35 12+8  35 13+4  35 17+4  35 35+8
ip  61
ip  55
mdrp[rp0,rnd,grey]  51
f_deltap    51 12-8  51 15-8  51 19-8  51 22-8  51 32-8
mirp[rp0,min,rnd,grey]  hstem 19
alignrp 1
mdrp[rnd,grey]  8
sloop   3
ip  71 66 16
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   32
mdrp[rnd,grey]  5
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 48
ip  43
mdrp[grey]  22
f_deltap    22 14+1  22 15+2  22 16+3
srp0    5
mdrp[rnd,grey]  11
ip  68
ip  64
ip  18
#
IUP[y]
""",

    #to_patak
    "uni0E0F": """
srp0    78
mdrp[rp0,rnd,grey]  35
f_deltap 35 18+8  35 21+8  35 22+8  35 26+8  35 31+8  
mirp[min,rnd,grey]  hstem 47
mdrp[rnd,grey]  41
f_deltap    41 12+8  41 13+4  41 17+4  41 41+8
ip  67
ip  61
mdrp[rp0,rnd,grey]  57
f_deltap    57 12-8  57 15-8  57 19-8  57 22-8  57 32-8
mirp[rp0,min,rnd,grey]  hstem 25
alignrp 1
mdrp[rnd,grey]  11
sloop   5
ip  76 71 19 21 2
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   38
mdrp[rnd,grey]  8
shp[rp2]    4
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 54
ip  49
ip  33
mdrp[grey]  28
f_deltap    28 14+1  28 15+2  28 16+3
srp0    8
mdrp[rnd,grey]  14
sloop   5
ip  74 70 22 21 2
#
IUP[y]
""",

    #tho_than
    "uni0E10": """
srp0    117
mdrp[rp0,rnd,grey]  7
ip  19
mdrp[rp0,rnd,grey]  12
ip  56
ip  50
ip  2
mdrp[rp0,rnd,grey]  44
f_deltap    44 12+8  44 15+8  44 16+8
mirp[min,rnd,grey]  hstem 16
mdrp[grey]  31
mdrp[rp0,rnd,grey]  96
mdrp[min,rnd,grey]  85
mdrp[rnd,grey]  91
ip  100
ip  106
mdrp[rnd,grey]  70
sloop    5
ip  115 111 80 82 61
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[grey]  13
f_deltap    13 14-1  13 15-2  13 16-3
mirp[rp0,rnd,grey]  vheight_shoot   23
ip  41
ip  19
mdrp[grey]  38
f_deltap    38 14+1  38 15+2  38 16+3
mdrp[rp0,rnd,grey]  10
ip  42
ip  18
mdrp[rnd,grey]  4
ip  53
ip  47
srp0    0
mdrp[rp0,min,rnd,grey]  94
mdrp[rnd,grey]  88
ip  103
ip  97
mdrp[rp0,rnd,grey]  59
alignrp 62
alignrp 67
mdrp[rnd,grey]  73
ip  113
ip  109
ip  82
ip  61
#
IUP[y]
""",

    #tho_than_descless
    "uni0E10.descless": """
srp0    59
mdrp[rp0,rnd,grey]  7
ip  19
mdrp[rp0,rnd,grey]  12
ip  56
ip  50
ip  2
mdrp[rp0,rnd,grey]  44
f_deltap    44 12+8  44 15+8  44 16+8
mirp[min,rnd,grey]  hstem 16
mdrp[grey]  31
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[grey]  13
f_deltap    13 14-1  13 15-2  13 16-3
mirp[rp0,rnd,grey]  vheight_shoot   23
ip  41
ip  19
mdrp[grey]  38
f_deltap    38 14+1  38 15+2  38 16+3
mdrp[rp0,rnd,grey]  10
ip  42
ip  18
mdrp[rnd,grey]  4
ip  53
ip  47
#
IUP[y]
""",

    #tho_nangmontho
    "uni0E11": """
srp0    66
mdrp[rp0,rnd,grey]  33
f_deltap    33 24-8
mdrp[rp0,rnd,grey]  27
f_deltap    27 18-8  27 19-8  27 20-8  27 21-8  27 23-8
ip  22
ip  63
ip  57
mdrp[rp0,rnd,white] 16
mdrp[grey]  40
mdrp[rp0,rnd,grey]  11
f_deltap    11 23+8
mirp[min,rnd,grey]  hstem 45
shp[rp2]    9
mdrp[rp0,rnd,grey]  2
f_deltap    2 12-8  2 16+8  2 28-8  2 29-8  2 34-8  2 37-8  2 38-8 
ip  49
mirp[min,rnd,grey]  hstem 53
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   9
alignrp 1
mdrp[grey]  46
mirp[rp0,rnd,grey]  vheight  38
alignrp 36
alignrp 51
mdrp[grey]  4
mdrp[rp0,rnd,grey]  24
ip  37
ip  19
mdrp[rnd,grey]  30
f_deltap    30 9+8  30 10+8  30 19+8  30 20+8  30 21+8
ip  60
ip  54
#
IUP[y]
""",

    #tho_phuthao
    "uni0E12": """
srp0    80
mdrp[rp0,rnd,white] 42
mirp[min,rnd,grey]  hstem 20
mdrp[rp0,rnd,grey]  13
f_deltap    13 12-8  13 17-8  13 18-8  13 19-8  13 21-8  13 22-8  13 24-8  13 26-8  13 27-8  13 28-8  13 29-8  13 30-8  13 31-8  13 32-8  13 33-8  13 34-8  13 36-8  13 37-8  13 38-8  13 39-8  13 40-8  
f_deltap    13 27-8
sloop   4
ip  29  65 59 35
mirp[min,rnd,grey]  hstem 50
mdrp[rp0,rnd,grey]  54
f_deltap    54 10+8  54 16+8  54 17+8  54 24-8 54 25-8  54 39-8  
alignrp 1
mirp[min,rnd,grey]  hstem 55
srp0    13
mdrp[rp0,rnd,grey]  9
mdrp[rnd,grey]  3
ip  77
ip  71
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
ALIGNRP     6
ALIGNRP     38
mdrp[grey]  53
mdrp[grey]  23
mdrp[rnd,grey]  12
ip  74
ip  68
ip  51
ip  3
mirp[rnd,grey]  vheight 54
mirp[rp0,rnd,grey]  vheight_shoot   47
alignrp     45
mdrp[rp0,min,rnd,grey]  46
mdrp[rp0,rnd,grey]  32
ip  17
mdrp[rnd,grey]  26
ip  62
ip  56
IUP[y]
""",

    #no_nane
    "uni0E13": """
srp0    75
mdrp[rp0,rnd,white] 24
f_deltap	24 16+8
ip  27
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  50
ip  54
mdrp[rp0,rnd,grey]  2
f_deltap    2 13+8  2 22-8  2 27-8  2 37-8  2 38-8  2 39-8
ip  26
ip  10
mirp[min,rnd,grey]  hstem 34
shp[rp2]    0
mdrp[rp0,rnd,grey]  38
mirp[rp0,min,rnd,grey]  hstem 39
mdrp[rp0,rnd,grey]  43
mdrp[rnd,grey]  49
ip  72
ip  66
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
alignrp 21
alignrp 46
mdrp[grey]  35
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 31
ip  26
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    21
mdrp[rp0,rnd,grey]  15
alignrp 37
sloop   4
ip  57 51 69 63
#
IUP[y]
""",

    #do_dek
    "uni0E14": """
srp0        49
mdrp[rp0,rnd,white] 30
mirp[min,rnd,grey]  hstem 8
f_deltap    8 17-4
mdrp[rp0,rnd,grey]  17
f_deltap    17 11-8  17 12-8  17 14-8  17 18+8
mdrp[rp0,rnd,grey]  23
f_deltap    23 19-8
ip  46
ip  40
ip  14
mdrp[rp0,rnd,grey]  2
f_deltap    2 16+8  2 22+8  2 23+8  2 26-8
mirp[min,rnd,grey]  hstem 36
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             26
mdrp[grey]  11
f_deltap    11 14-2  11 15-3  11 16-4
MIRP[rp0,rnd,grey]  vheight_shoot  33
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
mdrp[rp0,min,rnd,white]  20
f_deltap    20 9-8
mdrp[rnd,grey]  14
ip  43
ip  37
#
IUP[y]
""",

    #to_tao
    "uni0E15": """
srp0        52
mdrp[rp0,rnd,white] 31
mirp[min,rnd,grey]  hstem 9
f_deltap    9 17-4
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8  18 12-8  18 14-8  18 18+8
mdrp[rp0,rnd,grey]  24
f_deltap    24 19-8
ip  49
ip  43
ip  15
mdrp[rp0,rnd,grey]  2
f_deltap    2 16+8  2 22+8  2 23+8  2 26-8
mirp[min,rnd,grey]  hstem 39
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           1
ALIGNRP             27
mdrp[grey]  12
f_deltap    12 14-2  12 15-3  12 16-4
MIRP[rp0,rnd,grey]  vheight_shoot  36
alignrp     34
mdrp[grey]  4
f_deltap    4 14+1  4 15+2  4 16+3
shp[rp2]	7
mdrp[rp0,min,rnd,grey]	35
mdrp[rp0,min,rnd,grey]	5
mdrp[rp0,min,rnd,white]  21
mdrp[rnd,grey]  15
ip  46
ip  40
#
IUP[y]
""",

    #to_tung
    "uni0E16": """
srp0    47
mdrp[rp0,rnd,white] 24
f_deltap	24 26-8  24 27-8  24 28-8  24 29-8
ip  27
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  44
ip  38
mdrp[rp0,rnd,grey]  2
f_deltap    2 13+8  2 15+8  2 16+8  2 17-8  2 37-8
mirp[min,rnd,grey]  hstem 34
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             21
mirp[rp0,rnd,grey]  vheight_shoot    31
ip  25
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    21
mdrp[rnd,grey]  15
ip  41
ip  35
#
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
srp0    40
mdrp[rp0,rnd,grey]  20
f_deltap    20 12-8  20 18+8  20 19-8  20 21+8  20 22+8  20 26+8  
mirp[min,rnd,grey]  hstem 10
mdrp[rnd,grey]  15
f_deltap    15 12+8  15 13+4
ip  37
ip  31
mdrp[rp0,rnd,grey]  27
ip  23
ip  6
mirp[min,rnd,grey]  hstem 2
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     8
mdrp[grey]  21
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp     18
mdrp[grey]  4
f_deltap    4 14+1  4 15+2  4 16+3
mdrp[rnd,grey]  12
ip  34
ip  28
#
IUP[y]
""",

    #to_thong
    "uni0E18": """
srp0    39
mdrp[rp0,rnd,grey]  2
ip  11
ip  33
mirp[min,rnd,grey]  hstem 3
mdrp[rp0,rnd,grey]  8
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[grey]  23
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[grey]  5
mirp[rp0,rnd,grey]  vheight_shoot 15
ip  33
ip  11
mdrp[grey]  30
f_deltap    30 14+1  30 15+2  30 16+3
mdrp[rnd,grey]  3
ip  35
ip  9
#
IUP[y]
""",

    #no_nu
    "uni0E19": """
srp0    55
mdrp[rp0,rnd,grey]  12
f_deltap 12 39-8
alignrp 0
mirp[min,rnd,grey]  hstem 2
mdrp[rnd,grey]  7
f_deltap    7 12+8  7 13+4
ip  40
ip  34
mdrp[rp0,rnd,grey]  17
f_deltap    17 13+8  17 16+8  17 17+8  
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  21
f_deltap  21 22-8 21 23-8  21 24-8  21 26-8  21 27-8  21 29-8  21 35-8  21 37-8
mdrp[rnd,grey]  27
ip  46
ip  52
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     24
mdrp[grey]  13
mirp[rnd,grey]  vheight 16
mirp[rp0,rnd,grey]  vheight_shoot   10
mdrp[rnd,grey]  4
ip  37
ip  31
srp0    24
mdrp[rnd,grey]  18
ip  49
ip  43
ip  29
#
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
srp0    35
mdrp[rp0,rnd,grey]  14
f_deltap  14 18+8  14 21+8  14 22+8
mirp[min,rnd,grey]  hstem 4
mdrp[rnd,grey]  9
f_deltap    9 12+8  9 13+4
ip  2
ip  32
ip  26
mdrp[rp0,rnd,grey]  20
f_deltap    20 26+8
mirp[min,rnd,grey]  hstem 19
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mdrp[grey]  16
shp[rp2]    3
mirp[rnd,grey]  vheight 19
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
ip  29
ip  23
#
IUP[y]
""",

    #po_pla
    "uni0E1B": """
srp0    35
mdrp[rp0,rnd,grey]  14
f_deltap  14 18+8  14 21+8  14 22+8
mirp[min,rnd,grey]  hstem 4
mdrp[rnd,grey]  9
f_deltap    9 12+8  9 13+4
ip  2
ip  32
ip  26
mdrp[rp0,rnd,grey]  20
f_deltap    20 26+8
mirp[min,rnd,grey]  hstem 19
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mdrp[grey]  16
shp[rp2]    3
mirp[rnd,grey]  vheight_po 19
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
ip  29
ip  23
#
IUP[y]
""",

    #po_pung
    "uni0E1C": """
srp0    34
mdrp[rp0,rnd,white] 5
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 12-8  10 13-4
ip  31
ip  25
mdrp[rp0,rnd,grey]  20
alignrp     1
mirp[min,rnd,grey]  hstem 21
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight 20
ip  17
ip  2
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rnd,grey]  13
ip  28
ip  22
#
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
srp0    34
mdrp[rp0,rnd,white] 5
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 12-8  10 13-4
ip  31
ip  25
mdrp[rp0,rnd,grey]  20
alignrp     1
mirp[min,rnd,grey]  hstem 21
#
IUP[x]                                                            #
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 20
ip  17
ip  2
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rnd,grey]  13
ip  28
ip  22
#
IUP[y]
""",

    #po_pan
    "uni0E1E": """
srp0    34
mdrp[rp0,rnd,grey]  15
f_deltap	15 12-8  15 15-8  15 18+8  15 19-8  15 21+8  15 26+8  15 39-8  
alignrp 3
mirp[min,rnd,grey]  hstem 5
mdrp[rnd,grey]      10
f_deltap    10 12+8  10 13+4
ip  31
ip  25
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  hstem 20
shp[rp2]    1
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight 20
ip  17
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[rnd,grey]  7
ip  28
ip  22
#
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
srp0    34
mdrp[rp0,rnd,grey]  15
f_deltap	15 12-8  15 15-8  15 18+8  15 19-8  15 21+8  15 26+8  15 39-8
alignrp 3
mirp[min,rnd,grey]  hstem 5
mdrp[rnd,grey]      10
f_deltap    10 12+8  10 13+4
ip  31
ip  25
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  hstem 20
shp[rp2]    1
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rnd,grey]  vheight_po 20
ip  17
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[rnd,grey]  7
ip  28
ip  22
#
IUP[y]
""",

    #po_sampao
    "uni0E20": """
srp0    47
mdrp[rp0,rnd,grey]  12
f_deltap    12 12-8  12 18+8  12 21+8  12 26+8  12 39-8
mirp[min,rnd,grey]  hstem 24
mdrp[rnd,grey]  18
f_deltap    18 12+8  18 13+4
ip  44
ip  38
mdrp[rp0,rnd,grey]  34
f_deltap    34 19-8
mirp[min,rnd,grey]  hstem 2
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     15
mirp[rp0,rnd,grey]  vheight_shoot 31
ip      26
ip      10
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    15
mdrp[rnd,grey]  21
ip  41
ip  35
#
IUP[y]
""",

    #mo_ma
    "uni0E21": """
srp0    55
mdrp[rp0,rnd,grey]  25
f_deltap	25 14+8  25 17+8  25 18+8  25 21+8  25 22+8  25 26+8  25 30+8  
alignrp     3
mirp[min,rnd,grey]  hstem 15
mdrp[rnd,grey]  20
f_deltap    20 12+8  20 13+4
shp[rp2]    9
ip  40
ip  34
ip  52
ip  45
mdrp[rp0,rnd,grey]  30
f_deltap	30 14-8  30 17-8  30 27-8
mirp[min,rnd,grey]  hstem 29
shp[rp2]    1
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     6
mdrp[grey]  28
mirp[rnd,grey]  vheight 29
mirp[rp0,rnd,grey]  vheight_shoot 23
mdrp[rnd,grey]  17
ip  37
ip  31
srp0    6
mdrp[rnd,grey]  12
ip  49
ip  43
ip  26
ip  3
#
IUP[y]
""",

    #yo_yak
    "uni0E22": """
srp0    51
mdrp[rp0,rnd,grey]  30
f_deltap	30 15-8  30 18+8  30 19+8
mirp[min,rnd,grey]  hstem 3
mdrp[rp0,rnd,grey]  22
f_deltap    22 12+8  22 13+8  22 14+8  22 15+8  22 16+8  
mdrp[grey]  8
mdrp[rnd,grey]  14
f_deltap    14 9-8
ip  48
ip  42
srp0    30
mdrp[rp0,rnd,grey]  36
f_deltap	36 15+8  36 19-8  36 22-8  
ip  27
mirp[min,rnd,grey]  hstem 35
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[grey]  32
mirp[rnd,grey]  vheight 35
mirp[rp0,rnd,grey]  vheight_shoot 11
ip  27
ip  5
mdrp[rnd,grey]  17
ip  45
ip  39
ip  20
#
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
srp0    52
mdrp[rp0,rnd,grey]  37
f_deltap    37 12-8  
ip  12
mirp[min,rnd,grey]  hstem 9
mdrp[grey]   24
mdrp[rnd,grey]  3
f_deltap    3 12+8  3 13+4
ip  49
ip  43
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mdrp[rnd,grey]  6
ip  40
ip  46
mirp[rp0,rnd,grey]  vheight_shoot 16
ip  12
ip  34
mdrp[grey]  23
mdrp[grey]  31
f_deltap    31 14+1  31 15+2  31 16+3
#
IUP[y]
""",

    #ro_ru
    "uni0E24": """
srp0    47
mdrp[rp0,rnd,white] 24
f_deltap    24 26-8  24 27-8  24 28-8  24 29-8  24 37-8  
ip  27
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  44
ip  38
mdrp[rp0,rnd,grey]  2
f_deltap    2 13+8  2 15+8  2 16+8  2 17-8
mirp[min,rnd,grey]  hstem 34
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]           21
mdrp[rnd,grey]      1
mirp[rp0,rnd,grey]  vheight_shoot    31
ip  25
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    21
mdrp[rnd,grey]  15
ip  41
ip  35                                                   
#                                                        
IUP[y]
""",

    #lo_ling
    "uni0E25": """
srp0    51
mdrp[rp0,rnd,white] 17
f_deltap    17 22-8  17 24-8  17 36-8  17 37-8  17 38-8  17 39-8
mirp[min,rnd,grey]  hstem 6
ip  31
mdrp[rnd,grey]  12
f_deltap    12 12-8  12 13-4
mdrp[rp0,rnd,grey]  25
f_deltap    25 15+8  25 16+8  25 27-8  25 29-8  
alignrp 1
mirp[min,rnd,grey]  hstem 38
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     15
mdrp[grey]  24
mdrp[rnd,grey]  9
ip      45
ip      39
mirp[rp0,rnd,grey]  vheight_shoot 35
mdrp[grey]  28
f_deltap    28 14+1  28 15+2  28 16+3
mdrp[rp0,rnd,white] 21
f_deltap    21 9-8
mdrp[grey]  4
f_deltap    4 14+1  4 15+2  4 16+3
#
IUP[y]
""",

    #lo_lu
    "uni0E26": """
srp0    47
mdrp[rp0,rnd,grey]  12
f_deltap    12 18+8  12 21+8  12 22+8  12 26+8  
mirp[min,rnd,grey]  hstem 24
mdrp[rnd,grey]  18
f_deltap    18 12+8  18 13+4
ip  44
ip  38
mdrp[rp0,rnd,grey]  34
f_deltap    34 19-8
mirp[min,rnd,grey]  hstem 2
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   15
mdrp[rnd,grey]  1
mirp[rp0,rnd,grey]  vheight_shoot 31
ip      26
ip      10
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
srp0    15
mdrp[rnd,grey]  21
ip  41                                                   
ip  35                                                   
#
IUP[y]
""",

    #wo_wan
    "uni0E27": """
srp0    37
mdrp[rp0,rnd,grey]  23
ip  15
mirp[min,rnd,grey]  hstem 8
mdrp[rnd,grey]  3
f_deltap    3 12+8  3 13+4
ip  28
ip  34
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rnd,grey]  6
ip  31
ip  25
mirp[rp0,rnd,grey]  vheight_shoot 19
ip  15
mdrp[grey]  12
f_deltap    12 14+1  12 15+2  12 16+3
#
IUP[y]
""",

    #so_sala
    "uni0E28": """
srp0    63
mdrp[rp0,rnd,white] 38
f_deltap    38 30-8  38 31-8  38 32-8  38 34-8
mirp[min,rnd,grey]  hstem 14
mdrp[rnd,grey]      35
mdrp[rp0,rnd,grey]  20
f_deltap    20 11-8  20 12-8  20 14-8  
mdrp[rp0,rnd,grey]  25
f_deltap    25 13-8  25 18-8  25 19-8  
sloop   3
ip  31 50 54
mdrp[rp0,rnd,grey]  2
f_deltap    2 16+8  
mirp[min,rnd,grey]  hstem 50
srp0    35
mirp[min,rnd,grey]  hstem 34
ip  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]           0
ALIGNRP             34
mdrp[rnd,grey]      17
MIRP[rp0,rnd,grey]  vheight_shoot  41
mdrp[rp0,grey]  11
f_deltap    11 14+1  11 15+2  11 16+3
mdrp[rp0,min,rnd,grey]  23                               
mdap[rnd]       23                                       
f_deltap    23 17-8
mdrp[rp0,rnd,grey]  29
sloop   3
ip  57 51 31
IUP[y]
""",

    #so_rusi
    "uni0E29": """
srp0    71
mdrp[rp0,rnd,grey]  15
f_deltap 15 12+8  15 18+8  15 21+8  15 22+8  
mirp[min,rnd,grey]  hstem 4
mdrp[rnd,grey]  10
f_deltap    10 12+8  10 13+4
ip  2
ip  56
ip  50
mdrp[rp0,rnd,grey]  38
f_deltap    38 19-8
alignrp 44
mirp[min,rnd,grey]  hstem 37
shp[rp2]    20
srp1    37
srp2    15
sloop   5
ip  25 68 62 31 33
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]  0
mdrp[grey]  17
shp[rp2]    3
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 13
mdrp[rnd,grey]  6
ip  53
ip  47
srp0    0
mdrp[rp0,rnd,grey]  22
mdrp[grey]  33
mdrp[rnd,grey]  28
sloop   4
ip 65 59 39 44
#
IUP[y]
""",

    #so_sua
    "uni0E2A": """
srp0    63
mdrp[rp0,rnd,white] 17
f_deltap    17 22-8  17 24-8  17 36-8  17 37-8  17 38-8  17 39-8
mirp[min,rnd,grey]  hstem 6
mdrp[rnd,grey]  12
f_deltap    12 12-8  12 13-4
mdrp[rp0,rnd,grey]  25
f_deltap    25 15+8  25 16+8  25 27-8  25 29-8  
alignrp 1
mirp[min,rnd,grey]  hstem 50
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     15
mdrp[grey]  24
mdrp[rnd,grey]  9
ip      57
ip      51
mirp[rp0,rnd,grey]  vheight_shoot 41
mdrp[grey]  34
f_deltap    34 14+1  34 15+2  34 16+3
mdrp[rp0,rnd,white] 21
f_deltap    21 9-8
mdrp[grey]  4
f_deltap    4 14+1  4 15+2  4 16+3                       
#                                                        
IUP[y]
""",

    #ho_hib
    "uni0E2B": """
srp0    64
mdrp[rp0,rnd,grey]  20
f_deltap    20 18+8  20 19-8  20 21+8  20 22+8  20 26+8
mirp[min,rnd,grey]  hstem 10
mdrp[rnd,grey]  15
f_deltap    15 12+8  15 13+4
ip  49
ip  43
mdrp[rp0,rnd,grey]  39
f_deltap    39 12-8
alignrp 34
ip  23
ip  6
mirp[min,rnd,grey]  hstem 2
mdrp[rnd,grey]  28
ip  61
ip  55
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     8
mdrp[grey]  21
mirp[rp0,rnd,grey]  vheight_shoot 31
alignrp     18
mdrp[rnd,grey]  12
sloop   6
ip  45 40 58 52 25 37
mdrp[grey]  4                                       
#
IUP[y]
""",

    #lo_jula
    "uni0E2C": """
srp0    61
mdrp[rp0,rnd,grey]  15
f_deltap    15 19-8  15 21+8  15 22+8  
alignrp 3
mirp[min,rnd,grey]  hstem 5
mdrp[rnd,grey]      10
f_deltap    10 12+8  10 13+4
ip  46
ip  40
mdrp[rp0,rnd,grey]  36
alignrp 31
mirp[min,rnd,grey]  hstem 20
shp[rp2]    1
mdrp[rnd,grey]      24
ip  58
ip  52
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mdrp[grey]  19
shp[rp2]    16
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  17
mdrp[rnd,grey]  7
ip  43
ip  37                                             
mdrp[rp0,rnd,grey]  27
mdrp[rnd,grey]  21
ip  55
ip  49
ip  31
ip  36
#                                                  
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
srp0    45
mdrp[rp0,rnd,white] 2
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  7
f_deltap    7 12-8  7 13-4
ip  42
ip  36
mdrp[rp0,rnd,grey]  17
f_deltap    17 10-8  17 15+8  17 18+8  17 19-8  
ip  23
mirp[min,rnd,grey]  hstem 30
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight_shoot  27
mdrp[grey]  20
f_deltap    20 14+1  20 15+2  20 16+3
mdrp[rp0,rnd,white] 4
mdrp[rnd,grey]  10
ip  39
ip  33
#
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
srp0    59
mdrp[rp0,rnd,white] 2
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  7
f_deltap    7 12-8  7 13-4
ip  46
ip  40
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  hstem 56
srp0    2
mdrp[rp0,rnd,grey]  17
f_deltap    17 13+8  17 15+8  17 16+8
sloop   4
ip  51 19 28 32
mirp[min,rnd,grey]  hstem 34
#
IUP[x]
#    
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight_shoot  27
mdrp[grey]  53
f_deltap    53 14+1  53 15+2  53 16+3
mdrp[rp0,rnd,white] 4
f_deltap    4 12-8
ip  49
ip  21
mdrp[rnd,grey]  10
ip  43
ip  37
#
IUP[y]
""",

    #paiyannoi
    "uni0E2F": """
srp0    35
mdrp[rp0,rnd,white] 8
mdrp[rnd,grey]  14
ip  32
ip  26
ip  17
mdrp[rp0,rnd,grey]  2
alignrp 21
mirp[min,rnd,grey]  hstem 22
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 11
alignrp     21
mdrp[grey]  2
mdrp[rp0,min,rnd,grey]  17
ip  29
ip  23
mdrp[grey]  5
#
IUP[y]
""",

    #sara_a
    "uni0E30": """
srp0    60
mdrp[rp0,rnd,white] 3
alignrp 21
mdrp[rp0,rnd,grey]  9
alignrp 27
sloop   6
ip  57 51 45 39 26 11
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]  0
mdrp[grey]  11
mdrp[rnd,grey]  6
ip  14
ip  42
ip  36
mirp[rp0,rnd,grey]  vheight 24
mdrp[rp0,rnd,grey]  18
ip  54
ip  48
ip  32
mdrp[grey]  26
#
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   9
mdrp[rnd,grey]  3
ip  27
ip  21
ip  11
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rnd,grey]  6
ip  24
ip  18
ip  11
ip  14
f_deltap    11 15-2  11 16-2
#
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mdrp[rp0,rnd,grey]  2
ip  8
mirp[min,rnd,grey]  hstem 15
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
ip  8
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
#
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mdrp[rnd,grey]  4
ip  20
ip  14
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,grey]  17
ip  12
mdrp[min,rnd,grey]  8
#
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mdrp[min,rnd,grey]  11
mdrp[rnd,grey]  4
ip  22
ip  16
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,grey]  19
ip  14
mdrp[rp0,min,rnd,grey]  8
mdrp[min,rnd,grey]  12
#
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mdrp[rnd,grey]  4
ip  30
ip  24
mdrp[rp0,rnd,grey]  10
mdrp[rnd,grey]  16
f_deltap    16 14+8  16 15+8  16 16+8
ip  41
ip  35
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,min,rnd,grey]  27
ip  22
ip  19
mdrp[min,rnd,grey]  8
mdap[rnd]   19
mdrp[rnd,grey]  13
f_deltap    13 10+8  13 14+8  13 15+8  13 16+8  13 17+8  13 23+8  13 24+8
ip  38
ip  32
#
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mdrp[rnd,grey]  4
ip  26
ip  20
mdrp[rp0,min,rnd,grey]  15
mdrp[rp0,min,rnd,white] 13
mdrp[rp0,min,rnd,grey]  10
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,min,rnd,grey]  23
ip  18
mdrp[rp0,min,rnd,grey]  8
mdrp[min,rnd,grey]  11
shp[rp2]    16
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   0
mdrp[min,rnd,grey]  1
mdrp[rnd,grey]  7
ip  22
ip  16
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
mdrp[rp0,rnd,grey]  4
ip  19
ip  13
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   0
mdrp[rp0,min,rnd,grey]  15
mdrp[rp0,min,rnd,white] 13
mdrp[min,rnd,grey]  1
mdrp[rnd,grey]      7
f_deltap    7 15+8  7 16+8  
ip  26
ip  20
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
alignrp 15
mdrp[rp0,rnd,grey]  4
alignrp 13
ip  23
ip  17
mdrp[min,rnd,grey]   1
#
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   6
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    49
mdrp[rp0,rnd,white]  3
f_deltap    3 16-8  3 17-8
mdrp[min,rnd,grey]  26
shp[rp2]    39
mdrp[rp0,rnd,grey]  23
alignrp 2
alignrp 36
alignrp 5
mdrp[min,rnd,grey]  27
shp[rp2]    22
shp[rp2]    40
shp[rp2]    8
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  31
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  44
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   22
alignrp     2
mdrp[rnd,grey]  0
mdrp[min,rnd,grey]  27
shp[rp2]    26
mdrp[rp0,rnd,grey]  8
alignrp     5
ip  41
mdrp[rnd,grey]  7
mdrp[min,rnd,grey]  48
shp[rp2]    37
mdap[rnd]   41
alignrp     36
mdrp[min,rnd,grey]  35
shp[rp2]    24
ip  15
#
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    25
mdrp[rp0,rnd,white] 2
mirp[min,rnd,grey]  hstem 5
mdrp[rnd,grey]  10
f_deltap    10 12-8  10 13-4
ip  22
ip  16
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[rnd,grey]  vheight 4
mdrp[rnd,grey]  7
ip  19
ip  13
#
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mdrp[rp0,rnd,white] 2
mirp[min,rnd,grey]  hstem 32
mdrp[rnd,grey]  37
f_deltap    37 12-8  37 13-4
ip  49
ip  37
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rnd,grey]  34
ip  46
ip  40
mdrp[rp0,rnd,grey]  10
ip  28
ip  6
mdrp[grey]  25
f_deltap    25 14+1  25 15+2  25 16+3
#
IUP[y]
""",

    #sara_ai_maimoun
    "uni0E43": """
srp0    64
mdrp[rp0,rnd,white] 2
ip  20
mirp[min,rnd,grey]  hstem 32
mdrp[rnd,grey]  37
f_deltap    37 12-8  37 13-4
ip  49
ip  43
mdap[rnd]   20
mdrp[rp0,rnd,grey]  14
ip  61
ip  55
mdrp[rp0,rnd,grey]  8
mdrp[grey]  26
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rnd,grey]  34
ip  46
ip  40
mdrp[rp0,rnd,grey]  23
mdrp[rp0,rnd,grey]  11
mdrp[rnd,grey]  17
ip  58
ip  52
#
IUP[y]
""",

    #sara_ai_malai
    "uni0E44": """
srp0    37
mdrp[rp0,rnd,white] 2
ip  6
ip  13
mirp[min,rnd,grey]  hstem 17
mdrp[rnd,grey]  22
f_deltap    22 12-8  22 13-4
ip  34
ip  28
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rnd,grey]  19
ip  31
ip  25
mdrp[rp0,rnd,grey]  15
mdrp[grey]  3
mdrp[rp0,rnd,grey]  13
mdrp[grey]  5
#
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mdrp[rp0,rnd,white] 2
ip  8
mirp[min,rnd,grey]  hstem 15
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   16
mdrp[rnd,grey]  1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  5
f_deltap    5 14+1  5 15+2  5 16+3
#
IUP[y]
""",

    #maiyamok
    "uni0E46": """
srp0    38
mdrp[rp0,rnd,white] 19
mdrp[rnd,grey]  13
ip  35
ip  29
ip  8
mdrp[rp0,rnd,grey]  2
mirp[min,rnd,grey]  hstem 25
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   38
mdrp[rnd,grey]      0
mirp[rp0,rnd,grey]  vheight 21
alignrp 23
mdrp[grey]  6
f_deltap    6 14+1  6 15+2  6 16+3
shp[rp2]    4
mdrp[rp0,rnd,grey]  10
mdrp[rnd,grey]  16
ip  32
ip  26
#
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]   44
mdrp[rp0,rnd,grey]  38
ip  56
ip  50
mdrp[rp0,rnd,grey]  26
ip  28
ip  8
mdrp[min,rnd,grey]  11
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     8
mdrp[rnd,grey]  41
ip  53
ip  58
mdrp[rp0,min,rnd,grey]  5
alignrp 28
mdrp[rp0,min,rnd,grey]  31
mdrp[rp0,min,rnd,grey]  23
mdrp[min,rnd,grey]  14
IUP[y]
""",

    #maiek
    "uni0E48": """
mdap[rnd]   0
mdrp[min,rnd,grey]  1
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  3
#
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   14
mdrp[rnd,grey]  8
shp[rp2]    1
ip  28
ip  34
ip  5
ip  17
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rp0,rnd,grey]  5
ip  23
ip  17
mdrp[rp0,rnd,grey]  11
ip  31
ip  25
mdrp[grey]  21
#
IUP[y]
""",

    #maitri
    "uni0E4A": """
MDAP[rnd]   31
mdrp[min,rnd,grey]  5
mdrp[rp0,rnd,grey]  17
mdrp[rnd,grey]  23
ip  11
ip  47
ip  41
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     20
mdrp[rnd,grey]  14
ip  44
ip  38
ip  11
mdrp[rp0,rnd,grey]  26
alignrp 28
mdrp[grey]  9
shp[rp2]    7
#
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
mdap[rnd]   0
alignrp 8
mdrp[min,rnd,grey]  9
mdrp[rp0,min,rnd,grey]  1
alignrp 5
mdrp[min,rnd,grey]  3
# 
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,min,rnd,grey]  11
alignrp 2
mdrp[rp0,min,rnd,grey]  8
alignrp 5
mdrp[min,rnd,grey]  7
#
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   17
mdrp[rnd,grey]  3
ip  29
ip  23
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  6
ip  26
ip  20
mdrp[min,rnd,grey]  15
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
mdap[rnd]   9
mdrp[rnd,grey]  3
ip  21
ip  15
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rnd,grey]  6
ip  18
ip  12
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]   0
mdrp[grey]  24
mdrp[grey]  16
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  20
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[min,rnd,grey]  30
mdrp[rp0,rnd,grey]  24
mdrp[min,rnd,grey]  23
ip  7
mdrp[rp0,rnd,grey]  18
mdrp[min,rnd,grey]  13
#
IUP[y]
""",

    #fongman
    "uni0E4F": """
SRP0    56
mdrp[rp0,rnd,white]  5
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  23
srp1    29
srp2    23
sloop   4
ip  35 53 47 41
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
srp1    26
srp2    20
sloop   4
ip  38 50 44 32
#
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    24
mdrp[rp0,rnd,white] 3
mdrp[min,rnd,grey]  21
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  9
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0

mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
srp0    48
mdrp[rp0,rnd,white] 3
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,white] 27
f_deltap    27 11-8
mdrp[rp0,rnd,grey]  33
f_deltap    33 29-8
ip  45
ip  39
ip  25
mdrp[rp0,rnd,white] 9
mdrp[min,rnd,grey]  16
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  13
mdrp[min,rnd,grey]  25
mdrp[rnd,grey]  30
f_deltap    30 14+8
ip  42
ip  36
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  19
#
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
srp0    50
mdrp[rp0,rnd,white] 3
ip  5
ip  1
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,white] 30
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  24
ip  48
ip  41 
srp0    8
mdrp[rp0,rnd,white] 36
mdrp[min,rnd,grey]  13
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[rp0,rnd,grey]  32
alignrp 34
mdrp[grey]  17
shp[rp2]    15
mdrp[rp0,rnd,white] 21
mdrp[rnd,grey]  27
ip  44
ip  38
#
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
SRP0    52
mdrp[rp0,rnd,white] 28
mdrp[min,rnd,grey]  16
mdrp[rnd,grey]  22
ip  49
ip  43
mdrp[rp0,rnd,white] 10
mdrp[min,rnd,grey]  9
ip  33
mdrp[rp0,rnd,white] 3
mdrp[min,rnd,grey]  38
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     25
mdrp[rp0,rnd,grey]  35
alignrp 31
mdrp[min,rnd,grey]  6
shp[rp2]    13
srp0    25
mdrp[rp0,rnd,grey]  19
ip  46
ip  40
mdrp[grey]  10
#
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
srp0    51
mdrp[rp0,rnd,white]  7
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,white] 27
mdrp[rnd,grey]  33
sloop   5
ip  48 42 36 25 2
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     4
mdrp[min,rnd,grey]  38
shp[rp2]    23
mdrp[rnd,grey]  30
sloop   3
ip  45 39 36
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  17
#
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
srp0    73
mdrp[rp0,rnd,white]  7
mdrp[min,rnd,grey]  30
mdrp[rp0,rnd,white] 37
mdrp[rnd,grey]  43
sloop   5
ip  88 52 46 35 2
srp0    7
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  18
f_deltap    18 13+8
ip  70
ip  64
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     4
mdrp[min,rnd,grey]  48
shp[rp2]    33
mdrp[rnd,grey]  40
sloop   3
ip  55 49 46
mdrp[rp0,rnd,grey]  20
mdrp[rp0,min,rnd,grey]  27
mdrp[rnd,grey]  15
f_deltap    15 12+8
ip  67
ip  61
#
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
srp0    44
mdrp[rp0,rnd,white] 3
ip  21
ip  18
mdrp[rnd,grey]  9
ip  41
ip  35
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  29
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  11
mdrp[rnd,grey]  6
ip  38
ip  32
mdrp[rp0,rnd,grey]  26
mdrp[min,rnd,grey]  17
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    61
mdrp[rp0,rnd,white] 28
mdrp[min,rnd,grey]  16
mdrp[rnd,grey]  22
ip  58
ip  52
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  8
ip  33
srp0    28
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  38
mdrp[rp0,rnd,white] 42
mdrp[grey]  46
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     25
mdrp[grey]  40
mdrp[rp0,rnd,grey]  31
alignrp 35
mdrp[min,rnd,grey]  13
shp[rp2]    6
srp0    25
mdrp[rp0,rnd,grey]  19
ip  55
ip  49
mdrp[grey]  10
#
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
SRP0    52
mdrp[rp0,rnd,white] 6
mdrp[min,rnd,grey]  19
mdrp[rp0,rnd,grey]  37
sloop   5
ip  22 23 24 3 2
mdrp[rnd,grey]  31
ip  49
ip  43
ip  28
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]    0
alignrp 3
mdrp[min,rnd,grey]  26
shp[rp2]    22
f_deltap    22 16-2
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  16
srp0    26
mdrp[rnd,grey]  34
ip  46
ip  40
#
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    60
mdrp[rp0,rnd,white] 27
mdrp[min,rnd,grey]  10
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  21
ip  57
ip  51
mdrp[rp0,rnd,grey]  1
mdrp[min,rnd,grey]  0
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp 24
mdrp[rnd,grey]  18
ip  54
ip  48
ip  13
mdrp[rp0,rnd,grey]  34
alignrp 30
mdrp[min,rnd,grey]  44
shp[rp2]    7
#
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
SRP0    39
mdrp[rp0,rnd,white] 8
mdrp[rnd,grey]  14
ip  36
ip  30
ip  17
mdrp[rp0,rnd,grey]  25
mdrp[min,rnd,grey]  26
mdrp[rp0,min,rnd,white] 22
mdrp[min,rnd,grey]  21
shp[rp2]    2
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     24
mdrp[rp0,rnd,grey]  11
alignrp     21
ip  2
ip  22
ip  25
ip  26
mdrp[rp0,rnd,grey]  17
ip  33
ip  27
mdrp[min,rnd,grey]  5
#
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    68
mdrp[rp0,rnd,white] 3
mdrp[rp0,rnd,grey]  26
mdrp[rp0,rnd,grey]  9
ip  15
ip  65
ip  59
mdrp[min,rnd,grey]  20
#
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  23
srp1    23
srp2    29
ip  18
ip  62
ip  56
ip  12
#
IUP[y]
""",

#--------------LAO INSTRUCTION--------------------
#    #LAO LETTER KHO SUNG
    "uni0E82": """
SRP0    45
mdrp[rp0,rnd,white] 32
alignrp 6
mirp[min,rnd,grey]  hstem 17
mdrp[rnd,grey]  43
ip  0
ip  3
mdrp[rp0,rnd,grey]  37
mirp[min,rnd,grey]  hstem 12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]  30
mdrp[min,rnd,grey]  19
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,min,rnd,grey]  39
mdrp[rnd,grey]  4
ip  0
ip  1
srp1    4
srp2    19
ip  35
ip  14
#
IUP[y]
""",

#    #LAO LETTER KHO TAM
    "uni0E84": """
SRP0    57
mdrp[rp0,rnd,white] 19
alignrp 22
mirp[rp0,min,rnd,grey]  hstem 47
alignrp 37
mdrp[rnd,grey]  53
ip  49
ip  16
ip  10
ip  41
srp0    19
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 28
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   55
alignrp 30
mdrp[rnd,grey]  51
ip  8
ip  12
mirp[rp0,rnd,grey]  vheight_shoot 25
mdrp[min,rnd,grey]  34
srp0    51
mdrp[rp0,min,rnd,grey]  43
mdrp[rnd,grey]  39
ip  20
ip  4
#
IUP[y]
#""",


#    #LAO LETTER NGO
    "uni0E87": """
SRP0    34
mdrp[rp0,rnd,white] 12
alignrp 0
mirp[min,rnd,grey]  hstem 13
mdrp[rnd,grey]  22
ip  28
ip  32
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  hstem 5
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   34
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
srp0    34
mirp[rp0,rnd,grey]  vheight_shoot 3
mdrp[min,rnd,grey]  20
mdrp[rnd,grey]  24
ip  26
ip  30
IUP[y]
""",

#    #LAO LETTER CO
    "uni0E88": """
SRP0    42
mdrp[rp0,rnd,white] 37
mirp[min,rnd,grey]  hstem 36
mdrp[rp0,rnd,grey]  29
alignrp 18
mirp[min,rnd,grey]  hstem 16
srp0    36
mdrp[rp0,rnd,grey]  25
mdrp[rnd,grey]  21
ip  3
ip  9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   18
mirp[rp0,rnd,grey]  vheight_shoot 12
ip  36
mdrp[min,rnd,grey]  31
mdrp[rp0,rnd,white] 27
mdrp[rnd,grey]  23
ip  0
ip  6
ip  21
ip  29
IUP[y]
""",

#    #LAO LETTER SO TAM
    "uni0E8A": """
SRP0    58
mdrp[rp0,rnd,white] 45
alignrp 14
mirp[min,rnd,grey]  hstem 27
mdrp[rnd,grey]  56
ip  3
ip  9
mdrp[rp0,rnd,grey]  50
alignrp 41
mirp[min,rnd,grey] hstem 22
shp[rp2]    35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   43
mdrp[min,rnd,grey]  29
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[min,rnd,grey]  52
mdrp[rp0,rnd,grey]  12
ip  54
ip  0
ip  6
srp1    12
srp2    29
ip  47
ip  25
IUP[y]
""",

#    #LAO LETTER NYO
    "uni0E8D": """
SRP0    45
mdrp[rp0,rnd,white] 25
alignrp 29
mirp[rp0,min,rnd,grey]  hstem 12
alignrp 37
mdrp[rnd,grey]  33
ip  42
ip  9
ip  3
srp0    25
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  hstem 18
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   21
mdrp[min,rnd,grey]  14
mirp[rnd,grey]  vheight 17
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[rnd,grey]  35
ip  6
ip  0
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  42
ip  27
IUP[y]
""",

#    #LAO LETTER TO
    "uni0E95": """
SRP0    43
mdrp[rp0,rnd,white] 24
mirp[min,rnd,grey]  hstem 18
mdrp[rnd,grey]  20
f_deltap    20 16-8
ip  3
ip  9
mdrp[rp0,rnd,grey]  38
mirp[min,rnd,grey]  hstem 35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   37
alignrp 22
mdrp[rnd,grey]  18
ip  0
ip  6
mirp[rp0,rnd,grey]  vheight_shoot 27
alignrp 33
mdrp[min,rnd,grey]  15
shp[rp2] 40
mdrp[rp0,rnd,grey]  30
mdrp[min,rnd,grey]  12
IUP[y]
""",

#    #LAO LETTER THO SUNG
    "uni0E96": """
SRP0    36
mdrp[rp0,rnd,white] 19
mdrp[rp0,rnd,grey]  35
ip  5
ip  4
ip  23
mirp[rp0,min,rnd,grey]  hstem 14
mdrp[rnd,grey]  10
ip  1
ip  0
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 28
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   12
mdrp[rnd,grey]  30
mdrp[rnd,grey]  8
ip  1
ip  2
mirp[rp0,rnd,grey]  vheight_shoot   25
alignrp     21
mdrp[min,rnd,grey]  33
mdrp[rnd,grey]  17
ip  4
ip  7
ip  23
ip  35
IUP[y]
""",

#    #LAO LETTER NO
    "uni0E99": """
SRP0    33
mdrp[rp0,rnd,grey]  14
alignrp 7
mdrp[rp0,rnd,grey]  18
f_deltap    18 16-8
ip  4
ip  2
mirp[min,rnd,grey]  hstem 12
ip  30
mdrp[rp0,rnd,grey]  25
f_deltap    25 16+8
mirp[min,rnd,grey]  hstem 24
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   28
alignrp     32
mdrp[min,rnd,grey]  21
shp[rp2]    8
mirp[rnd,grey]  vheight 24
mirp[rp0,rnd,grey]  vheight_shoot   16
mdrp[rnd,grey]  12
ip  3
ip  0
IUP[y]
""",

#    #LAO LETTER BO
    "uni0E9A": """
SRP0    26
mdrp[rp0,rnd,white] 4
alignrp 8
mirp[min,rnd,grey]  hstem 15
mdrp[rnd,grey]  12
f_deltap    12 16-8
ip  1
ip  0
ip  6
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  hstem 21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   24
mdrp[min,rnd,grey]  17
mirp[rnd,grey]  vheight 20
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rnd,grey]  6
ip  1
ip  2
IUP[y]
""",

#    #LAO LETTER PO
    "uni0E9B": """
SRP0    26
mdrp[rp0,rnd,white] 4
alignrp 8
mirp[min,rnd,grey]  hstem 15
mdrp[rnd,grey]  12
f_deltap    12 16-8
ip  1
ip  0
ip  6
mdrp[rp0,rnd,grey]  20
mirp[min,rnd,grey]  hstem 21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   24
mdrp[min,rnd,grey]  17
mirp[rnd,grey]  vheight_po 20
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rnd,grey]  6
ip  1
ip  2
IUP[y]
""",


#    #LAO LETTER  PHO SUNG
    "uni0E9C": """
SRP0    75
mdrp[rp0,rnd,white] 34
mirp[min,rnd,grey]  hstem 43
mdrp[rnd,grey]  39
ip  15
ip  21
mdrp[rp0,rnd,grey]  48
mirp[rp0,min,rnd,grey]  hstem 49
ip  28
mdrp[rp0,rnd,grey]  71
alignrp 61
mirp[min,rnd,grey]  hstem 54
mdrp[rnd,grey]  57
ip  3
ip  9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
alignrp 25
mdrp[min,rnd,grey]  45
shp[rp2]    52
mirp[rp0,rnd,grey]  vheight_shoot 37
alignrp 59
mdrp[rp0,rnd,grey]  41
alignrp 55
ip  12
ip  0
ip  18
ip  6
ip  61
ip  70
mdrp[rnd,grey]  48
IUP[y]
""",

#    #LAO LETTER FO TAM 
    "uni0E9D": """
SRP0    49
mdrp[rp0,rnd,white] 14
mirp[min,rnd,grey]  hstem 23
mdrp[rnd,grey]  19
ip  40
ip  46
mdrp[rp0,rnd,grey]  28
mirp[rp0,min,rnd,grey]  hstem 29
ip  8
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  hstem 35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   10
alignrp 5
mdrp[min,rnd,grey]  25
shp[rp2]    32
mirp[rnd,grey]  vheight_po 35
mirp[rp0,rnd,grey]  vheight_shoot 17
mdrp[rp0,rnd,grey]  21
ip  37
ip  43
mdrp[rnd,grey]  28
IUP[y]
""",                                       

#    #LAO LETTER PHO TAM 
    "uni0E9E": """
SRP0    45
mdrp[rp0,rnd,white] 32
alignrp 36
mirp[min,rnd,grey]  hstem 43
mdrp[rnd,grey]  40
f_deltap    40 15-8  40 16-8
ip  3
ip  9
ip  34
mdrp[rp0,rnd,grey]  15
mirp[rp0,min,rnd,grey]  hstem 16
ip  28
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 22
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
alignrp 26
mdrp[min,rnd,grey]  12
shp[rp2]    19
mirp[rnd,grey]  vheight 22
mirp[rp0,rnd,grey]  vheight_shoot 38
mdrp[rp0,rnd,grey]  34
ip  0
ip  6
mdrp[rnd,grey]  15
IUP[y]
""",

#    #LAO LETTER FO SUNG 
    "uni0E9F": """
SRP0    45
mdrp[rp0,rnd,white] 32
alignrp 36
mirp[min,rnd,grey]  hstem 43
mdrp[rnd,grey]  40
f_deltap    40 15-8  40 16-8
ip  3
ip  9
ip  34
mdrp[rp0,rnd,grey]  15
mirp[rp0,min,rnd,grey]  hstem 16
ip  28
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 22
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
alignrp 26
mdrp[min,rnd,grey]  12
shp[rp2]    19
mirp[rnd,grey]  vheight_po 22
mirp[rp0,rnd,grey]  vheight_shoot 38
mdrp[rp0,rnd,grey]  34
ip  0
ip  6
mdrp[rnd,grey]  15
IUP[y]
""",

#    #LAO LETTER MO
    "uni0EA1": """
SRP0    24
mdrp[rp0,rnd,grey]  17
mdrp[rp0,rnd,grey]  23
ip  21
mirp[min,rnd,grey]  hstem 2
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  hstem 9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   11
alignrp 15
mdrp[min,rnd,grey]  4
alignrp 21
mdrp[rnd,grey]  19
mirp[rnd,grey]  vheight 7
shp[rp2]    1
IUP[y]
""",

#    #LAO LETTER YO
    "uni0EA2": """
SRP0    45
mdrp[rp0,rnd,white] 24
alignrp 29
mirp[rp0,min,rnd,grey]  hstem 12
alignrp 37
mdrp[rnd,grey]  41
mdrp[rnd,grey]  33
ip  9
ip  3
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  hstem 17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   21
mdrp[min,rnd,grey]  14
mirp[rnd,grey]  vheight_po  17
mirp[rp0,rnd,grey]  vheight_shoot 31
mdrp[rp0,rnd,grey]  35
ip  37
ip  6
ip  10
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  42
ip  27
IUP[y]
""",

#    #LAO LETTER LO LING
    "uni0EA3": """
SRP0    44
mdrp[rp0,rnd,white] 16
alignrp 34
mirp[min,rnd,grey]  hstem 25
mdrp[rnd,grey]  38
ip  3
ip  9
mdrp[rp0,rnd,grey]  12
mirp[min,rnd,grey]  hstem 29
shp[rp2]    20
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   31
mdrp[min,rnd,grey]  42
mdrp[rp0,rnd,grey]  36
ip  0
ip  6
ip  40
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  27
srp0    31
mirp[rp0,rnd,grey]  vheight_shoot 18
mdrp[min,rnd,grey]  23
IUP[y]
""",

#    #LAO LETTER LO LOOT
    "uni0EA5": """
SRP0    47
mdrp[rp0,rnd,white] 28
alignrp 43
mirp[min,rnd,grey]  hstem 42
mdrp[rnd,grey]  24
f_deltap    24 16-8
ip  3
ip  9
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  hstem 14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   17
alignrp 26
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  22
ip  0
ip  6
mdrp[rp0,rnd,grey]  20
mdrp[min,rnd,grey]  30
srp0    17
mirp[rp0,rnd,grey]  vheight_shoot   12
mdrp[min,rnd,grey]  38
srp1    38
srp2    30
ip  42
IUP[y]
""",

#    #LAO LETTER WO
    "uni0EA7": """
SRP0    32
mdrp[rp0,rnd,white] 16
alignrp 6
mirp[min,rnd,grey]  hstem 31
mdrp[rnd,grey]  20
f_deltap  20 16-8
ip  1
ip  2
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  hstem 10
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   13
mdrp[min,rnd,grey]  24
mdrp[rnd,grey]  18
ip  0
ip  3
mirp[rp0,rnd,grey]  vheight_shoot 8
ip  31
mdrp[min,rnd,grey]  29
IUP[y]
""",

#    #LAO LETTER SO SUNG
    "uni0EAA": """
SRP0    59
mdrp[rp0,rnd,white] 17
alignrp 44
mirp[min,rnd,grey]  hstem 57
mdrp[rnd,grey]  40
f_deltap    40 16-8
ip  3
ip  9
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  hstem 30
ip  53
ip  21
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  hstem 28
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   33
alignrp 42
mdrp[min,rnd,grey]  49
mdrp[rp0,rnd,grey]  38
ip  0
ip  6
mdrp[rp0,rnd,grey]  36
mdrp[min,rnd,grey]  46
srp0    33
mirp[rp0,rnd,grey]  vheight_shoot   19
mdrp[min,rnd,grey]  55
srp1    38
srp2    30                                 
ip  51
mdap[rnd]   15
mdrp[min,rnd,grey]  51
IUP[y]
""",

#    #LAO LETTER  HO SUNG
    "uni0EAB": """
SRP0    55
mdrp[rp0,rnd,white] 16
alignrp 20
mirp[min,rnd,grey]  hstem 27
mdrp[rp0,rnd,grey]  53
sloop 7
ip  2 6 24 37 9 13 41
mirp[min,rnd,grey]  hstem 31
mdrp[rp0,rnd,grey]  45
mirp[min,rnd,grey]  hstem 48
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   47
alignrp     14
mdrp[min,rnd,grey]  29
mirp[rp0,rnd,grey]  vheight_shoot 43
alignrp 39
alignrp 22
mdrp[min,rnd,grey]  50
mdrp[rnd,grey]  34
shp[rp2]    18
ip  0
ip  4
ip  7
ip  11
IUP[y]
""",

#    #LAO LETTER  O
    "uni0EAD": """
SRP0    46
mdrp[rp0,rnd,white] 14
alignrp 25
mirp[min,rnd,grey]  hstem 42
mdrp[rnd,grey]  29
f_deltap    29 16-8
ip  3
ip  9
mdrp[rp0,rnd,grey]  38
alignrp 36
mirp[min,rnd,grey]  hstem 18
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   21
mdrp[min,rnd,grey]  33
mdrp[rp0,rnd,grey]  27
ip  0
ip  6
mdrp[rp0,rnd,grey]  12
mdrp[min,rnd,grey]  44
srp0    21
mirp[rp0,rnd,grey]  vheight_shoot 16
mdrp[min,rnd,grey]  40
IUP[y]
""",

#    #LAO LETTER  HO TAM
    "uni0EAE": """
SRP0    55
mdrp[rp0,rnd,white] 18
alignrp 45
mirp[min,rnd,grey]  hstem 35
mdrp[rnd,grey]  49
ip  3
ip  9
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 39
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   41
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  47
ip  0
ip  6
ip  53
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  37
mdrp[rp0,rnd,grey]  29
mdrp[min,rnd,grey]  24
srp0    41
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[min,rnd,grey]  33
IUP[y]
""",

#    #LAO LETTER  ELLIPSIS
    "uni0EAF": """
SRP0    37
mdrp[rp0,rnd,white] 15
mirp[min,rnd,grey]  hstem 25
mdrp[rp0,rnd,grey]  23
mdrp[rp0,rnd,grey]  19
ip  1
ip  0
mdrp[rp0,rnd,grey]  34
ip  30
ip  8
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,rnd,grey]  vheight_shoot 17
mdrp[min,rnd,grey]  23
mdrp[rp0,rnd,grey]  21
ip  1
ip  2
mdrp[rp0,rnd,grey]  27
mdrp[min,rnd,grey]  13
IUP[y]
""",

#    #LAO VOWEL SIGN MAI KAN
    "uni0EB1": """
mdap[rnd]   0
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  5
mdrp[rnd,grey]  9
f_deltap    9 16-8  9 17-8  9 18-8
ip  24
ip  21
IUP[x]
#
SVTCA[y-axis]
MDAP[RND]   2
mdrp[min,rnd,grey]  13
mdrp[rnd,grey]  7
ip  22
ip  26
IUP[y]
""",

#    #LAO VOWEL SIGN AA
    "uni0EB2": """
SRP0    23
mdrp[rp0,rnd,white] 15
mdrp[rnd,grey]  11
f_deltap    11 16-8
ip  17
ip  21
ip  9
mdrp[rp0,rnd,grey]  5
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   4
mirp[rp0,rnd,grey]  vheight_shoot 0
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  9
mdrp[rnd,grey]  13
ip  22
ip  19
IUP[y]
""",

#    #LAO VOWEL SIGN I
    "uni0EB4": """
MDAP[rnd]   9
mdrp[min,rnd,grey]  14
mdrp[rp0,rnd,grey]  5
ip  2
ip  12
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   11
alignrp 3
mdrp[rp0,min,rnd,grey]  12
shp[rp2]    2
mdrp[rp0,min,rnd,grey]  16
mdrp[min,rnd,grey]  7
IUP[y]
""",

#    #LAO VOWEL SIGN II
    "uni0EB5": """
MDAP[rnd]   9
mdrp[min,rnd,grey]  18
mdrp[rp0,rnd,grey]  5
ip  2
ip  16
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
alignrp 3
mdrp[rp0,min,rnd,grey]  16
shp[rp2]    2
shp[rp2]    11
mdrp[rp0,min,rnd,grey]  20
mdrp[min,rnd,grey]  7
IUP[y]
""",

#    #LAO VOWEL SIGN Y
    "uni0EB6": """
MDAP[rnd]   9
mdrp[min,rnd,grey]  14
mdrp[rp0,rnd,grey]  5
ip  2
ip  12
ip  21
ip  18
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   11
alignrp 3
mdrp[rp0,min,rnd,grey]  12
shp[rp2]    2
mdrp[rp0,min,rnd,grey]  16
ip  21
ip  20
mdrp[min,rnd,grey]  7
IUP[y]
""",

#    #LAO VOWEL SIGN YY
    "uni0EB7": """
MDAP[rnd]   9
mdrp[min,rnd,grey]  18
mdrp[rp0,rnd,grey]  5
ip  2
ip  16
ip  25
ip  22
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
alignrp 3
mdrp[rp0,min,rnd,grey]  16
shp[rp2]    2
shp[rp2]    11
mdrp[rp0,min,rnd,grey]  20
ip  25
ip  24
mdrp[min,rnd,grey]  7
IUP[y]
""",

#    #LAO VOWEL SIGN U
    "uni0EB8": """
MDAP[rnd]   19
mdrp[min,rnd,grey]  9
mdrp[rnd,grey]  13
ip  1
ip  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   15
mdrp[rnd,grey]  11
ip  1
ip  2
IUP[y]
""",

#    #LAO VOWEL SIGN UU
    "uni0EB9": """
MDAP[rnd]   24
mdrp[min,rnd,grey]  23
mdrp[rp0,rnd,grey]  8
alignrp 12
mdrp[min,rnd,grey]  18
mdrp[rnd,grey]  15
ip  2
ip  5
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   23
alignrp     14
mdrp[rnd,grey]  10
ip  2
ip  3
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  20
IUP[y]
""",

#    #LAO VOWEL SIGN MAI KON
    "uni0EBB": """
mdap[rnd]   0
mdrp[min,rnd,grey]  5
mdrp[rp0,rnd,grey]  15
mdrp[rnd,grey]  11
f_deltap    11 16-8
ip  25
ip  23
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   13
alignrp 2
mdrp[rp0,rnd,grey]  19
ip  25
ip  27
mdrp[min,rnd,grey]  7
IUP[y]
""",

#    #LAO SEMIVOWEL SIGN LO
    "uni0EBC": """
mdap[rnd]   13
mdrp[rnd,grey]  17
ip  6
ip  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   15
alignrp 8
mdrp[min,rnd,grey]  22
mdrp[rp0,rnd,grey]  19
ip  4
ip  0
mdrp[min,rnd,grey]  11
IUP[y]
""",

#    #LAO TONE MAI EK
    "uni0EC8": """
mdap[rnd]   1
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   2
mdrp[min,rnd,grey]  1
IUP[y]
""",

#    #LAO TONE MAI THO
    "uni0EC9": """
mdap[rnd]   8
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  17
alignrp     13
mdrp[rp0,rnd,grey]  21
ip  6
ip  2
mdrp[min,rnd,grey]  15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   12
mdrp[min,rnd,grey]  13
shp[rp2]    24
mdrp[rp0,rnd,grey]  15
mdrp[rnd,grey]  19
ip  4
ip  0
IUP[y]
""",

#    #LAO TONE MAI TI
    "uni0ECA": """
mdap[rnd]   13
mdrp[rnd,grey]  25
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  2
mdrp[min,rnd,grey]  40
mdrp[rp0,rnd,grey]  49
mdrp[min,rnd,grey]  45
srp0    13
mdrp[rp0,rnd,grey]  19
mdrp[min,rnd,grey]  20
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp     25
mdrp[min,rnd,grey]  42
shp[rp2]    26
shp[rp2]    15
mdrp[rp0,rnd,grey]  47
alignrp 34
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  11
alignrp 4
mdrp[min,rnd,grey]  38
shp[rp2]    30
IUP[y]
""",

#    #LAO TONE MAI CATAWA
    "uni0ECB": """
mdap[rnd]   8
alignrp 5
mdrp[min,rnd,grey]  7
mdrp[rp0,min,rnd,grey]  11
shp[rp2]    2
mdrp[min,rnd,grey]  0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   9
mdrp[rp0,min,rnd,grey]  8
alignrp 11
mdrp[rp0,min,rnd,grey]  5
alignrp 2
mdrp[min,rnd,grey]  4
IUP[y]
""",

#    #LAO TONE NIGGAHITA
    "uni0ECD": """
mdap[rnd]   4
mdrp[min,rnd,grey]  0
ip  8
ip  12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   6
mdrp[min,rnd,grey]  2
ip  12
ip  10
IUP[y]
""",

##    #LAO LETTER 
#    "uni0EXX": """
#SRP0    0
#IUP[x]
##
#SVTCA[y-axis]
#MDAP[rnd]   0
#IUP[y]
#""",

##    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#IUP[x]
##
#SVTCA[y-axis]
#MDAP[rnd]   0
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
